==> apache-asterixdb-0.9.4-source-release.zip: apache-asterixdb-0.9.4/asterix-app/src/main/java/org/apache/asterix/api/http/ctx/StatementExecutorContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.asterix.api.http.ctx;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.apache.asterix.translator.IStatementExecutorContext;
import org.apache.hyracks.api.job.JobId;

public class StatementExecutorContext implements IStatementExecutorContext {

    private final Map<String, JobId> runningQueries = new ConcurrentHashMap<>();

    @Override
    public JobId getJobIdFromClientContextId(String clientContextId) {
        return runningQueries.get(clientContextId);
    }

    @Override
    public void put(String clientContextId, JobId jobId) {
        runningQueries.put(clientContextId, jobId);
    }

    @Override
    public JobId removeJobIdFromClientContextId(String clientContextId) {
        return runningQueries.remove(clientContextId);
    }
}

==> apache-asterixdb-0.9.4.1-source-release.zip: apache-asterixdb-0.9.4.1/asterix-app/src/main/java/org/apache/asterix/api/http/ctx/StatementExecutorContext.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements.  See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership.  The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License.  You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
package org.apache.asterix.api.http.ctx;

import java.util.Map;
import java.util.concurrent.ConcurrentHashMap;

import org.apache.asterix.common.api.IClientRequest;
import org.apache.asterix.translator.IStatementExecutorContext;

public class StatementExecutorContext implements IStatementExecutorContext {

    private final Map<String, IClientRequest> runningQueries = new ConcurrentHashMap<>();

    @Override
    public IClientRequest get(String clientContextId) {
        return runningQueries.get(clientContextId);
    }

    @Override
    public void put(String clientContextId, IClientRequest req) {
        runningQueries.put(clientContextId, req);
    }

    @Override
    public IClientRequest remove(String clientContextId) {
        return runningQueries.remove(clientContextId);
    }
}
